@@ -16,9 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- * May, 2000. Implemented on FreeBSD 4.0-RELEASE (Compaq Armada M700)
- *
- $Id: properties.c,v 1.45 2005/03/20 10:20:55 kmaraas Exp $
+ $Id: properties.c,v 1.50 2005/07/09 05:48:58 ryanl Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -27,15 +25,6 @@
 
 #include <stdio.h>
 
-#ifdef __FreeBSD__
-#include <machine/apm_bios.h>
-#elif defined(__NetBSD__) || defined(__OpenBSD__)
-#include <sys/param.h>
-#include <machine/apmvar.h>
-#elif __linux__
-#include <apm.h>
-#endif
-
 #include <sys/file.h>
 #include <sys/ioctl.h>
 #include <sys/types.h>
@@ -49,20 +38,18 @@
 #include <time.h>
 #include <unistd.h>
 
-#include <gdk/gdkx.h>
+#include <gtk/gtk.h>
 
 #include <glade/glade.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkmessagedialog.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtkspinbutton.h>
 
 #include <gconf/gconf-client.h>
-#include <libgnome/gnome-init.h>
-#include <libgnomeui/gnome-window-icon.h>
+
+#include <libgnome/libgnome.h>
+
+#include <libgnomeui/libgnomeui.h>
+
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
-/*#include <status-docklet.h>*/
 
 #include "battstat.h"
 
@@ -70,12 +57,6 @@
 #define gettext_noop(String) (String)
 #endif
 
-#if defined(__NetBSD__) || defined(__OpenBSD__)
-extern struct apm_power_info apminfo;
-#else
-extern struct apm_info apminfo;
-#endif
-
 #define NEVER_SENSITIVE		"never_sensitive"
 
 /* set sensitive and setup NEVER_SENSITIVE appropriately */
@@ -100,6 +81,44 @@ soft_set_sensitive (GtkWidget *w, gboolean sensitivity)
 }
 #endif /* 0 */
 
+static void
+combo_ptr_cb (GtkWidget *combo_ptr, gpointer data)
+{
+	ProgressData *battstat = data;
+	
+	if (gtk_combo_box_get_active (GTK_COMBO_BOX (combo_ptr)))
+		battstat->red_value_is_time = TRUE;
+	else
+		battstat->red_value_is_time = FALSE;
+	
+	panel_applet_gconf_set_bool (PANEL_APPLET (battstat->applet),
+			"red_value_is_time",
+			battstat->red_value_is_time,
+			NULL);
+}
+
+static void
+spin_ptr_cb (GtkWidget *spin_ptr, gpointer data)
+{
+	ProgressData *battstat = data;
+
+	battstat->red_val = gtk_spin_button_get_value_as_int (
+			GTK_SPIN_BUTTON (spin_ptr));
+	/* automatically calculate orangle and yellow values from the
+	 * red value
+	 */
+	battstat->orange_val = battstat->red_val * ORANGE_MULTIPLIER;
+	battstat->orange_val = CLAMP (battstat->orange_val, 0, 100);
+
+	battstat->yellow_val = battstat->red_val * YELLOW_MULTIPLIER;
+	battstat->yellow_val = CLAMP (battstat->yellow_val, 0, 100);
+	
+	panel_applet_gconf_set_int (PANEL_APPLET (battstat->applet),
+			"red_value",
+			battstat->red_val,
+			NULL);
+}
+
 static gboolean
 key_writable (PanelApplet *applet, const char *key)
 {
@@ -119,7 +138,7 @@ key_writable (PanelApplet *applet, const char *key)
 }
 
 static void
-show_bat_toggled (GtkToggleButton *button, gpointer data)
+radio_traditional_toggled (GtkToggleButton *button, gpointer data)
 {
   ProgressData   *battstat = data;
   PanelApplet *applet = PANEL_APPLET (battstat->applet);
@@ -127,10 +146,10 @@ show_bat_toggled (GtkToggleButton *button, gpointer data)
   
   toggled = gtk_toggle_button_get_active (button);
  
-  if (!( toggled || battstat->showtext || battstat->showstatus)) {
+  /* if (!( toggled || battstat->showtext || battstat->showstatus)) {
     gtk_toggle_button_set_active (button, !toggled);
     return;
-  }
+  } */
 
   battstat->showbattery = toggled;
   reconfigure_layout( battstat );
@@ -141,7 +160,7 @@ show_bat_toggled (GtkToggleButton *button, gpointer data)
 }
 
 static void
-show_status_toggled (GtkToggleButton *button, gpointer data)
+radio_ubuntu_toggled (GtkToggleButton *button, gpointer data)
 {
   ProgressData   *battstat = data;
   PanelApplet *applet = PANEL_APPLET (battstat->applet);
@@ -149,10 +168,10 @@ show_status_toggled (GtkToggleButton *button, gpointer data)
   
   toggled = gtk_toggle_button_get_active (button);
   
-  if (!( toggled || battstat->showtext || battstat->showbattery)) {
+  /* if (!( toggled || battstat->showtext || battstat->showbattery)) {
     gtk_toggle_button_set_active (button, !toggled);
     return;
-  }
+  } */
   
   battstat->showstatus = toggled;
   reconfigure_layout( battstat );
@@ -192,27 +211,6 @@ show_text_toggled (GtkToggleButton *button, gpointer data)
   				 battstat->showtext, NULL);
 }
 
-static void
-suspend_changed (GtkEditable *editable, gpointer data)
-{
-  ProgressData   *battstat = data;
-  PanelApplet *applet = PANEL_APPLET (battstat->applet);
-  gchar *cmd;
-  
-  cmd = gtk_editable_get_chars (editable, 0, -1);
-  if (!cmd)
-  	return;
-  
-  if (battstat->suspend_cmd)
-    g_free (battstat->suspend_cmd);
-  battstat->suspend_cmd = g_strdup(cmd);
-  g_free (cmd);
-  
-  panel_applet_gconf_set_string (applet, "suspend_command", 
-  				 battstat->suspend_cmd, NULL);
-
-}
-
 static void
 lowbatt_toggled (GtkToggleButton *button, gpointer data)
 {
@@ -222,6 +220,8 @@ lowbatt_toggled (GtkToggleButton *button, gpointer data)
   battstat->lowbattnotification = gtk_toggle_button_get_active (button);
   panel_applet_gconf_set_bool   (applet,"low_battery_notification", 
   				 battstat->lowbattnotification, NULL);  
+
+  hard_set_sensitive (battstat->hbox_ptr, battstat->lowbattnotification);
 }
 
 static void
@@ -235,60 +235,15 @@ full_toggled (GtkToggleButton *button, gpointer data)
   				 battstat->fullbattnot, NULL);  
 }
 
-static void
-prefs_help_cb (GtkWindow *dialog)
-{
-	GError *error = NULL;
-	static GnomeProgram *applet_program = NULL;
-	
-	if (!applet_program) {
-		int argc = 1;
-		char *argv[2] = { "battstat" };
-		applet_program = gnome_program_init ("battstat", VERSION,
-						      LIBGNOME_MODULE, argc, argv,
-     						      GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);
-	}
-
-	gnome_help_display_desktop_on_screen (
-			applet_program, "battstat", "battstat", "battstatt-prefs",
-			gtk_widget_get_screen (GTK_WIDGET (dialog)),
-			&error);
-
-	if (error) {
-		GtkWidget *error_dialog;
-
-		error_dialog = gtk_message_dialog_new (
-				NULL,
-				GTK_DIALOG_DESTROY_WITH_PARENT,
-				GTK_MESSAGE_ERROR,
-				GTK_BUTTONS_OK,
-				_("There was an error displaying help: %s"),
-				error->message);
-
-		g_signal_connect (error_dialog, "response",
-				  G_CALLBACK (gtk_widget_destroy),
-				  NULL);
-
-		gtk_window_set_resizable (GTK_WINDOW (error_dialog), FALSE);
-		gtk_window_set_screen (GTK_WINDOW (error_dialog),
-				       gtk_widget_get_screen (GTK_WIDGET (dialog)));
-		gtk_widget_show (error_dialog);
-		g_error_free (error);
-	}
-}
-
 static void
 response_cb (GtkDialog *dialog, gint id, gpointer data)
 {
-  ProgressData   *battstat = data;
-  
-  if (id == GTK_RESPONSE_HELP) {
-  	prefs_help_cb (GTK_WINDOW (dialog));
-	return;
-  }
-  
-  gtk_widget_hide (GTK_WIDGET (battstat->prop_win));
+  ProgressData *battstat = data;
   
+  if (id == GTK_RESPONSE_HELP)
+    battstat_show_help (battstat, "battstat-appearance");
+  else
+    gtk_widget_hide (GTK_WIDGET (battstat->prop_win));
 }
 
 void
@@ -297,8 +252,11 @@ prop_cb (BonoboUIComponent *uic,
 	 const char        *verb)
 {
   GladeXML  *glade_xml;
-  GtkWidget *layout_table;
+  GtkWidget *layout_table, *combo_ptr, *spin_ptr;
   GConfClient *client;
+  GtkListStore *liststore;
+  GtkCellRenderer *renderer;
+  GtkTreeIter iter;
   gboolean   inhibit_command_line;
 
   client = gconf_client_get_default ();
@@ -328,56 +286,103 @@ prop_cb (BonoboUIComponent *uic,
   g_signal_connect (G_OBJECT (battstat->lowbatt_toggle), "toggled",
   		    G_CALLBACK (lowbatt_toggled), battstat);
 
-  if ( ! key_writable (PANEL_APPLET (battstat->applet), "low_battery_notification")) {
+  if (!key_writable (PANEL_APPLET (battstat->applet),
+			  "low_battery_notification"))
+  {
 	  hard_set_sensitive (battstat->lowbatt_toggle, FALSE);
   }
 
+  battstat->hbox_ptr = glade_xml_get_widget (glade_xml, "hbox_ptr");
+  hard_set_sensitive (battstat->hbox_ptr, battstat->lowbattnotification);
+
+  combo_ptr = glade_xml_get_widget (glade_xml, "combo_ptr");
+  g_signal_connect (G_OBJECT (combo_ptr), "changed",
+		  G_CALLBACK (combo_ptr_cb), battstat);
+
+  liststore = gtk_list_store_new (1, G_TYPE_STRING);
+  gtk_combo_box_set_model (GTK_COMBO_BOX (combo_ptr),
+		  GTK_TREE_MODEL (liststore));
+  gtk_cell_layout_clear (GTK_CELL_LAYOUT (combo_ptr));
+  renderer = gtk_cell_renderer_text_new ();
+  gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo_ptr),
+		  renderer, TRUE);
+  gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo_ptr),
+		  renderer,
+		  "text", 0,
+		  NULL);
+  gtk_list_store_append (liststore, &iter);
+  /* TRANSLATOR: this is a selectable item in a drop-down menu to end
+   * this sentence:
+   *   "Warn when battery charge drops to: [XX] percent".
+   */
+  gtk_list_store_set (liststore, &iter, 0, _("Percent"), -1);
+  gtk_list_store_append (liststore, &iter);
+  /* TRANSLATOR: this is a selectable item in a drop-down menu to end
+   * this sentence:
+   *   "Warn when battery charge drops to: [XX] minutes remaining"
+   */
+  gtk_list_store_set (liststore, &iter, 0, _("Minutes Remaining"), -1);
+
+  spin_ptr = glade_xml_get_widget (glade_xml, "spin_ptr");
+  gtk_spin_button_set_value (GTK_SPIN_BUTTON (spin_ptr),
+		  battstat->red_val);
+  g_signal_connect (G_OBJECT (spin_ptr), "value-changed",
+		  G_CALLBACK (spin_ptr_cb), battstat);
+
+  if (battstat->red_value_is_time)
+	  gtk_combo_box_set_active (GTK_COMBO_BOX (combo_ptr), 1);
+  else
+	  gtk_combo_box_set_active (GTK_COMBO_BOX (combo_ptr), 0);
+
   battstat->full_toggle = glade_xml_get_widget (glade_xml, "full_toggle");
   g_signal_connect (G_OBJECT (battstat->full_toggle), "toggled",
   		    G_CALLBACK (full_toggled), battstat);
 
-  if ( ! key_writable (PANEL_APPLET (battstat->applet), "full_battery_notification")) {
+  if (!key_writable (PANEL_APPLET (battstat->applet),
+			  "full_battery_notification"))
+  {
 	  hard_set_sensitive (battstat->full_toggle, FALSE);
   }
-  if(battstat->fullbattnot) {
-     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (battstat->full_toggle), TRUE);
+  if (battstat->fullbattnot)
+  {
+     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (battstat->full_toggle),
+		     TRUE);
   }
-  if(battstat->lowbattnotification) {
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (battstat->lowbatt_toggle), TRUE);
+  if (battstat->lowbattnotification)
+  {
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (battstat->lowbatt_toggle),
+		    TRUE);
   }
 
-  battstat->suspend_entry = glade_xml_get_widget (glade_xml, "suspend_entry");
-  g_signal_connect (G_OBJECT(battstat->suspend_entry), "changed",
-		    G_CALLBACK(suspend_changed), battstat);
-
-  gtk_entry_set_text (GTK_ENTRY (battstat->suspend_entry), battstat->suspend_cmd); 
-  if ( ! key_writable (PANEL_APPLET (battstat->applet), "suspend_command") ||
-      inhibit_command_line) {
-	  hard_set_sensitive (battstat->suspend_entry, FALSE);
-	  hard_set_sensitive (glade_xml_get_widget (glade_xml, "suspend_label"), FALSE);
-  }
   layout_table = glade_xml_get_widget (glade_xml, "layout_table");
 
-  battstat->radio_lay_batt_on = glade_xml_get_widget (glade_xml, "show_batt_toggle");
+  battstat->radio_traditional_battery = glade_xml_get_widget (glade_xml,
+		  "battery_view_2");
+  g_signal_connect (G_OBJECT (battstat->radio_traditional_battery), "toggled",
+  		    G_CALLBACK (radio_traditional_toggled), battstat);
 
-  if ( ! key_writable (PANEL_APPLET (battstat->applet), "show_battery"))
-	  hard_set_sensitive (battstat->radio_lay_batt_on, FALSE);
+  if (!key_writable (PANEL_APPLET (battstat->applet), "show_battery"))
+	  hard_set_sensitive (battstat->radio_traditional_battery, FALSE);
   
-  if(battstat->showbattery) {
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (battstat->radio_lay_batt_on), TRUE);
+  if (battstat->showbattery)
+  {
+    gtk_toggle_button_set_active (
+		    GTK_TOGGLE_BUTTON (battstat->radio_traditional_battery),
+		    TRUE);
   }
-  g_signal_connect (G_OBJECT (battstat->radio_lay_batt_on), "toggled",
-  		    G_CALLBACK (show_bat_toggled), battstat);
+  
+  battstat->radio_ubuntu_battery = glade_xml_get_widget (glade_xml,
+		  "battery_view");
+  g_signal_connect (G_OBJECT (battstat->radio_ubuntu_battery), "toggled",
+  		    G_CALLBACK (radio_ubuntu_toggled), battstat);
 
-  battstat->radio_lay_status_on = glade_xml_get_widget (glade_xml, "show_status_toggle");
-  g_signal_connect (G_OBJECT (battstat->radio_lay_status_on), "toggled",
-  		    G_CALLBACK (show_status_toggled), battstat);
-
-  if ( ! key_writable (PANEL_APPLET (battstat->applet), "show_status"))
-	  hard_set_sensitive (battstat->radio_lay_status_on, FALSE);
+  if (!key_writable (PANEL_APPLET (battstat->applet), "show_status"))
+	  hard_set_sensitive (battstat->radio_ubuntu_battery, FALSE);
 	
-  if(battstat->showstatus) {
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (battstat->radio_lay_status_on), TRUE);
+  if (battstat->showstatus)
+  {
+    gtk_toggle_button_set_active (
+		    GTK_TOGGLE_BUTTON (battstat->radio_ubuntu_battery), TRUE);
   }
 
   battstat->radio_text_1 = glade_xml_get_widget (glade_xml, "show_text_radio");
@@ -393,7 +398,7 @@ prop_cb (BonoboUIComponent *uic,
   g_signal_connect (G_OBJECT (battstat->check_text), "toggled",
 		  G_CALLBACK (show_text_toggled), battstat);
   
-  if ( ! key_writable (PANEL_APPLET (battstat->applet), "show_text"))
+  if (!key_writable (PANEL_APPLET (battstat->applet), "show_text"))
   {
 	  hard_set_sensitive (battstat->check_text, FALSE);
 	  hard_set_sensitive (battstat->radio_text_1, FALSE);
@@ -434,7 +439,8 @@ prop_cb (BonoboUIComponent *uic,
 			  FALSE);
   }
 
-   gtk_dialog_set_default_response (GTK_DIALOG (battstat->prop_win), GTK_RESPONSE_CLOSE);
+   gtk_dialog_set_default_response (GTK_DIALOG (battstat->prop_win),
+		   GTK_RESPONSE_CLOSE);
    gtk_window_set_resizable (GTK_WINDOW (battstat->prop_win), FALSE);
    gtk_dialog_set_has_separator (GTK_DIALOG (battstat->prop_win), FALSE);
    
